aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorFurquan Shaikh <furquan@chromium.org>2017-03-06 22:47:14 -0800
committerFurquan Shaikh <furquan@google.com>2017-03-08 20:52:00 +0100
commit40d4089f5c03e192e52ef1c8bbeb9873c992dd04 (patch)
treec7c7f9cbafbe1cc901b645edb37b153e0b4f7d18 /src
parentf8401cddb82adbc8c5a8268f6215cf3cf903cfbf (diff)
mainboard/google/poppy: Add EC_HOST_EVENT_MODE_CHANGE to wakeup source
Allow EC mode change event to wake AP up in S3. BUG=b:35775085 BRANCH=None TEST=Compiles successfully for poppy. Change-Id: I6f1546c60aef6620e22cdce2fab3a2709e6556a1 Signed-off-by: Furquan Shaikh <furquan@chromium.org> Reviewed-on: https://review.coreboot.org/18608 Tested-by: build bot (Jenkins) Reviewed-by: Duncan Laurie <dlaurie@chromium.org> Reviewed-by: Aaron Durbin <adurbin@chromium.org>
Diffstat (limited to 'src')
-rw-r--r--src/mainboard/google/poppy/ec.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/mainboard/google/poppy/ec.h b/src/mainboard/google/poppy/ec.h
index 5ee71ceb97..7b53bfe12e 100644
--- a/src/mainboard/google/poppy/ec.h
+++ b/src/mainboard/google/poppy/ec.h
@@ -44,10 +44,14 @@
(EC_HOST_EVENT_MASK(EC_HOST_EVENT_LID_OPEN) |\
EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
/* EC can wake from S3 with lid or power button or key press */
#define MAINBOARD_EC_S3_WAKE_EVENTS \
(MAINBOARD_EC_S5_WAKE_EVENTS |\
- EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED))
+ EC_HOST_EVENT_MASK(EC_HOST_EVENT_KEY_PRESSED) |\
+ EC_HOST_EVENT_MASK(EC_HOST_EVENT_MODE_CHANGE))
/* Log EC wake events plus EC shutdown events */
#define MAINBOARD_EC_LOG_EVENTS \
@@ -44,10 +44,14 @@
(EC_HOST_EVENT_MASK(EC_HOST_EVENT_LID_OPEN) |\
EC_HOST_EVENT_MASK(EC_HOST_EVENT_POWER_BUTTON))
-/* EC can wake from S3 with lid or power button or key press */
+/*
+ * EC can wake from S3 with lid or power button or key press or
+ * mode change event.
+ */
#define MAINBOARD_EC_S3_WAKE_EVENTS \
(MAINBOARD_EC_S5_WAKE_EVENTS |\